@@ -72,3 +72,23 @@ TrainStation KnowledgeDb::stationForBenerailId(BenerailStationId id)
 {
     return lookupStation(id, benerail_table);
 }
+
+TrainStation KnowledgeDb::stationForIataCode(IataCode iataCode)
+{
+    return lookupStation(iataCode, iata_table);
+}
+
+TrainStation KnowledgeDb::stationForAmtrakStationCode(AmtrakStationCode code)
+{
+    return lookupStation(code, amtrak_table);
+}
+
+TrainStation KnowledgeDb::stationForViaRailStationCode(ViaRailStationCode code)
+{
+    return lookupStation(code, viarail_table);
+}
+
+TrainStation KnowledgeDb::stationForUkRailwayStationCode(UKRailwayStationCode code)
+{
+    return lookupStation(code, uk_table);
+}
