@@ -20,7 +20,7 @@ public:
     void expandNode(ExtractorDocumentNode &node, const ExtractorEngine *engine) const override;
     void preExtract(ExtractorDocumentNode &node, const ExtractorEngine *engine) const override;
     QJSValue contentToScriptValue(const ExtractorDocumentNode &node, QJSEngine *engine) const override;
-    void postExtract(ExtractorDocumentNode &node) const override;
+    void postExtract(ExtractorDocumentNode &node, const ExtractorEngine *engine) const override;
     void destroyNode(ExtractorDocumentNode &node) const override;
 };
 
